@@ -12,7 +12,7 @@ from .utils import (exec_bionetgen_task, add_model_attribute_change_to_task, add
                     get_variables_results_from_observable_results, add_variables_to_model)
 from .warnings import IgnoredBnglFileContentWarning
 from biosimulators_utils.combine.exec import exec_sedml_docs_in_archive
-from biosimulators_utils.config import get_config
+from biosimulators_utils.config import get_config, Config  # noqa: F401
 from biosimulators_utils.log.data_model import CombineArchiveLog, TaskLog  # noqa: F401
 from biosimulators_utils.viz.data_model import VizFormat  # noqa: F401
 from biosimulators_utils.report.data_model import ReportFormat, VariableResults, SedDocumentResults  # noqa: F401
@@ -27,11 +27,7 @@ import warnings
 __all__ = ['exec_sedml_docs_in_combine_archive', 'exec_sed_task']
 
 
-def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
-                                       return_results=False,
-                                       report_formats=None, plot_formats=None,
-                                       bundle_outputs=None, keep_individual_outputs=None,
-                                       raise_exceptions=True):
+def exec_sedml_docs_in_combine_archive(archive_filename, out_dir, config=None):
     """ Execute the SED tasks defined in a COMBINE/OMEX archive and save the outputs
 
     Args:
@@ -43,12 +39,7 @@ def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
             * HDF5: directory in which to save a single HDF5 file (``{ out_dir }/reports.h5``),
               with reports at keys ``{ relative-path-to-SED-ML-file-within-archive }/{ report.id }`` within the HDF5 file
 
-        return_results (:obj:`bool`, optional): whether to return the result of each output of each SED-ML file
-        report_formats (:obj:`list` of :obj:`ReportFormat`, optional): report format (e.g., csv or h5)
-        plot_formats (:obj:`list` of :obj:`VizFormat`, optional): report format (e.g., pdf)
-        bundle_outputs (:obj:`bool`, optional): if :obj:`True`, bundle outputs into archives for reports and plots
-        keep_individual_outputs (:obj:`bool`, optional): if :obj:`True`, keep individual output files
-        raise_exceptions (:obj:`bool`, optional): whether to raise exceptions
+        config (:obj:`Config`, optional): BioSimulators common configuration
 
     Returns:
         :obj:`tuple`:
@@ -59,21 +50,17 @@ def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
     sed_doc_executer = functools.partial(exec_sed_doc, exec_sed_task)
     return exec_sedml_docs_in_archive(sed_doc_executer, archive_filename, out_dir,
                                       apply_xml_model_changes=False,
-                                      return_results=return_results,
-                                      report_formats=report_formats,
-                                      plot_formats=plot_formats,
-                                      bundle_outputs=bundle_outputs,
-                                      keep_individual_outputs=keep_individual_outputs,
-                                      raise_exceptions=raise_exceptions)
+                                      config=config)
 
 
-def exec_sed_task(sed_task, variables, log=None):
+def exec_sed_task(sed_task, variables, log=None, config=None):
     """ Execute a task and save its results
 
     Args:
        sed_task (:obj:`Task`): task
        variables (:obj:`list` of :obj:`Variable`): variables that should be recorded
        log (:obj:`TaskLog`, optional): log for the task
+       config (:obj:`Config`, optional): BioSimulators common configuration
 
     Returns:
         :obj:`tuple`:
@@ -104,8 +91,9 @@ def exec_sed_task(sed_task, variables, log=None):
         * BioNetGen
         * :obj:`get_variables_results_from_observable_results`
     """
-    config = get_config()
-    log = log or TaskLog()
+    config = config or get_config()
+    if config.LOG and not log:
+        log = TaskLog()
 
     if config.VALIDATE_SEDML:
         raise_errors_warnings(
@@ -157,10 +145,11 @@ def exec_sed_task(sed_task, variables, log=None):
         variable_results[key] = variable_results[key][-(sed_task.simulation.number_of_points + 1):]
 
     # log action
-    log.algorithm = alg_kisao_id
-    log.simulator_details = {
-        'actions': bionetgen_task.actions,
-    }
+    if config.LOG:
+        log.algorithm = alg_kisao_id
+        log.simulator_details = {
+            'actions': bionetgen_task.actions,
+        }
 
     # return the values of the variables and log
     return variable_results, log
